package cz.novoj.business.interceptor;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.aop.MethodBeforeAdvice;
import org.springframework.util.ClassUtils;

import java.lang.reflect.Method;

/**
 * Naive security interceptor implementation. Allows calls of subsequent methods only when block state is false.
 *
 * @author Jan Novotn, FG Forrest a.s. (c) 2007
 * @version $Id: $
 */
public class NaiveSecurityInterceptor implements MethodBeforeAdvice {
	private static Log log = LogFactory.getLog(NaiveSecurityInterceptor.class);
	private boolean block;

	public boolean isBlock() {
		return block;
	}

	public void setBlock(boolean block) {
		this.block = block;
	}

	public void before(Method method, Object[] args, Object target) throws Throwable {
		if (block) {
			String qualifiedMethodName = ClassUtils.getQualifiedMethodName(method);
			String message = "Method call [" + qualifiedMethodName + "] was blocked.";
			if (log.isInfoEnabled()) {
				log.info(message);
			}
			throw new RuntimeException(message);
		}
		//authorize call
		if (log.isInfoEnabled()) {
			String qualifiedMethodName = ClassUtils.getQualifiedMethodName(method);
			String message = "Method call [" + qualifiedMethodName + "] was allowed.";
			log.info(message);
		}
	}

}
