/*
 * BusinessObjectTest.java
 * JUnit based test
 *
 * Created on 18. leden 2007, 9:31
 */

package cz.novoj.emt.stub;

import cz.novoj.emt.exception.SendException;
import cz.novoj.emt.BusinessObject;
import org.junit.*;
import static org.junit.Assert.*;

/**
 * Test for business object with Stubs.
 * 
 * @author Rodina Novotnych
 */
public class BusinessObjectStubTest {
    private BusinessObject tested;
	private StubLogger loggerStub;
	private StubMessageSender messageStub;

	/**
	 * Test initialization.
	 */
	@Before
	public void init() {
		tested = new BusinessObject();
        loggerStub = new StubLogger();
        messageStub = new StubMessageSender();

        tested.setLogger(loggerStub);
        tested.setMessageSender(messageStub);
	}


	/**
     * Tests performBusinessLogic with test stubs.
     **/
    @Test 
    public void testPerformBusinessLogicWithStubsLowerBound() {        
        tested.performBussinesLogic(1);

		assertEquals(0, loggerStub.getCallCounter());
		assertEquals(1, messageStub.getCallCounter());
		assertEquals(BusinessObject.RECEIVER_ONE, messageStub.getReceiver());
		assertEquals(BusinessObject.SENDER, messageStub.getSender());
		assertEquals(BusinessObject.SUBJECT, messageStub.getSubject());
		assertEquals(BusinessObject.BODY_LOWER_BOUND, messageStub.getBody());
    }
    
    /**
     * Tests performBusinessLogic with test stubs.
     **/
    @Test 
    public void testPerformBusinessLogicWithStubsHigherBound() {
        tested.performBussinesLogic(11);
        
        assertEquals(0, loggerStub.getCallCounter());
        assertEquals(1, messageStub.getCallCounter());
		assertEquals(BusinessObject.RECEIVER_TWO, messageStub.getReceiver());
		assertEquals(BusinessObject.SENDER, messageStub.getSender());
		assertEquals(BusinessObject.SUBJECT, messageStub.getSubject());
		assertEquals(BusinessObject.BODY_HIGHER_BOUND, messageStub.getBody());
    }
    
    /**
     * Tests performBusinessLogic with test stubs.
     **/
    @Test 
    public void testPerformBusinessLogicWithStubsWithException() {
        StubExceptionMessageSender messageStubThrowingException = new StubExceptionMessageSender();
        
        tested.setMessageSender(messageStubThrowingException);
        tested.performBussinesLogic(1);

		assertEquals(1, loggerStub.getCallCounter());
		assertTrue(loggerStub.getLastException() instanceof SendException);
    }
    
}
